pub enum WebSocketMessage {
NewMessage {
id: String,
sender: String,
recipient: String,
content: String,
timestamp: i64,
nonce: u64,
delivery_status: String,
},
PeerConnected {
peer_id: String,
},
PeerDisconnected {
peer_id: String,
},
DeliveryStatusUpdate {
message_id: String,
new_status: String,
},
}Expand description
Represents messages that can be sent over the WebSocket to the web UI.
Variants
NewMessage
A new chat message has been received or sent.
Fields
PeerConnected
A peer has connected to the network.
PeerDisconnected
A peer has disconnected from the network.
DeliveryStatusUpdate
The delivery status of a message has been updated.